<?php

/**
 * Filter file.
 *
 * @package    filter_enriched_shortcode
 * @copyright  2018 Enriched Academy
 * @author     Enriched Academy <www.enrichedacademy.com>
 */

defined('MOODLE_INTERNAL') || die();

use filter_enriched_shortcode\local\processor\standard_processor;
use filter_enriched_shortcode\local\registry\plugin_registry;

require_once($CFG->dirroot . '/filter/enriched_shortcode/lib/helpers.php');


/**
 * Filter class.
 *
 * @package    filter_enriched_shortcode
 * @copyright  2018 Enriched Academy
 * @author     Enriched Academy <www.enrichedacademy.com>
 */
class filter_enriched_shortcode extends moodle_text_filter {

    /** @var processor The processor. */
    private $processor;

    /**
     * The filtering occurs here.
     *
     * @param string $text HTML content.
     * @param array $options Options passed to the filter.
     * @return string The new content.
     */
    public function filter($text, array $options = []) {
        $env = filter_enriched_shortcode_make_env($this->context, $options);
        $processor = $this->get_processor();
        $processor->set_env($env);
        return $processor->process($text);
    }

    /**
     * Get the processor.
     *
     * @return standard_processor
     */
    private function get_processor() {
        if ($this->processor === null) {
            $this->processor = new standard_processor(new plugin_registry());
        }
        return $this->processor;
    }

}
